@@ -8,20 +8,21 @@
     :copyright: (c) 2014 by Shipeng Feng.
     :license: BSD, see LICENSE for more details.
 """
+
 import sys
 import time
 from datetime import datetime
 from uuid import uuid4
+
 try:
     import cPickle as pickle
 except ImportError:
-    import pickle
+    import pickle  # type: ignore[no-redef]
 
 from flask.sessions import SessionInterface as FlaskSessionInterface
 from flask.sessions import SessionMixin
+from itsdangerous import BadSignature, Signer, want_bytes
 from werkzeug.datastructures import CallbackDict
-from itsdangerous import Signer, BadSignature, want_bytes
-
 
 PY2 = sys.version_info[0] == 2
 if not PY2:
@@ -40,6 +41,7 @@ class ServerSideSession(CallbackDict, SessionMixin):
     def __init__(self, initial=None, sid=None, permanent=None):
         def on_update(self):
             self.modified = True
+
         CallbackDict.__init__(self, initial, on_update)
         self.sid = sid
         if permanent:
@@ -68,20 +70,17 @@ class SqlAlchemySession(ServerSideSession):
 
 
 class SessionInterface(FlaskSessionInterface):
-
     def _generate_sid(self):
         return str(uuid4())
 
     def _get_signer(self, app):
         if not app.secret_key:
             return None
-        return Signer(app.secret_key, salt='flask-session',
-                      key_derivation='hmac')
+        return Signer(app.secret_key, salt="flask-session", key_derivation="hmac")
 
 
 class NullSessionInterface(SessionInterface):
-    """Used to open a :class:`flask.sessions.NullSession` instance.
-    """
+    """Used to open a :class:`flask.sessions.NullSession` instance."""
 
     def open_session(self, app, request):
         return None
@@ -105,6 +104,7 @@ class RedisSessionInterface(SessionInterface):
     def __init__(self, redis, key_prefix, use_signer=False, permanent=True):
         if redis is None:
             from redis import Redis
+
             redis = Redis()
         self.redis = redis
         self.key_prefix = key_prefix
@@ -129,11 +129,11 @@ class RedisSessionInterface(SessionInterface):
                 return self.session_class(sid=sid, permanent=self.permanent)
 
         if not PY2 and not isinstance(sid, text_type):
-            sid = sid.decode('utf-8', 'strict')
-        val = self.redis.get(self.key_prefix + sid)
-        if val is not None:
+            sid = sid.decode("utf-8", "strict")
+        value = self.redis.get(self.key_prefix + sid)
+        if value is not None:
             try:
-                data = self.serializer.loads(val)
+                data = self.serializer.loads(value)
                 return self.session_class(data, sid=sid)
             except:
                 return self.session_class(sid=sid, permanent=self.permanent)
@@ -145,8 +145,9 @@ class RedisSessionInterface(SessionInterface):
         if not session:
             if session.modified:
                 self.redis.delete(self.key_prefix + session.sid)
-                response.delete_cookie(app.session_cookie_name,
-                                       domain=domain, path=path)
+                response.delete_cookie(
+                    app.session_cookie_name, domain=domain, path=path
+                )
             return
 
         # Modification case.  There are upsides and downsides to
@@ -164,17 +165,26 @@ class RedisSessionInterface(SessionInterface):
         if self.has_same_site_capability:
             conditional_cookie_kwargs["samesite"] = self.get_cookie_samesite(app)
         expires = self.get_expiration_time(app, session)
-        val = self.serializer.dumps(dict(session))
-        self.redis.setex(name=self.key_prefix + session.sid, value=val,
-                         time=total_seconds(app.permanent_session_lifetime))
+        value = self.serializer.dumps(dict(session))
+        self.redis.setex(
+            name=self.key_prefix + session.sid,
+            value=value,
+            time=total_seconds(app.permanent_session_lifetime),
+        )
         if self.use_signer:
             session_id = self._get_signer(app).sign(want_bytes(session.sid))
         else:
             session_id = session.sid
-        response.set_cookie(app.session_cookie_name, session_id,
-                            expires=expires, httponly=httponly,
-                            domain=domain, path=path, secure=secure,
-                            **conditional_cookie_kwargs)
+        response.set_cookie(
+            app.session_cookie_name,
+            session_id,
+            expires=expires,
+            httponly=httponly,
+            domain=domain,
+            path=path,
+            secure=secure,
+            **conditional_cookie_kwargs,
+        )
 
 
 class MemcachedSessionInterface(SessionInterface):
@@ -196,7 +206,7 @@ class MemcachedSessionInterface(SessionInterface):
         if client is None:
             client = self._get_preferred_memcache_client()
             if client is None:
-                raise RuntimeError('no memcache module found')
+                raise RuntimeError("no memcache module found")
         self.client = client
         self.key_prefix = key_prefix
         self.use_signer = use_signer
@@ -204,7 +214,7 @@ class MemcachedSessionInterface(SessionInterface):
         self.has_same_site_capability = hasattr(self, "get_cookie_samesite")
 
     def _get_preferred_memcache_client(self):
-        servers = ['127.0.0.1:11211']
+        servers = ["127.0.0.1:11211"]
         try:
             import pylibmc
         except ImportError:
@@ -252,13 +262,13 @@ class MemcachedSessionInterface(SessionInterface):
 
         full_session_key = self.key_prefix + sid
         if PY2 and isinstance(full_session_key, unicode):
-            full_session_key = full_session_key.encode('utf-8')
-        val = self.client.get(full_session_key)
-        if val is not None:
+            full_session_key = full_session_key.encode("utf-8")
+        value = self.client.get(full_session_key)
+        if value is not None:
             try:
                 if not PY2:
-                    val = want_bytes(val)
-                data = self.serializer.loads(val)
+                    value = want_bytes(value)
+                data = self.serializer.loads(value)
                 return self.session_class(data, sid=sid)
             except:
                 return self.session_class(sid=sid, permanent=self.permanent)
@@ -269,12 +279,13 @@ class MemcachedSessionInterface(SessionInterface):
         path = self.get_cookie_path(app)
         full_session_key = self.key_prefix + session.sid
         if PY2 and isinstance(full_session_key, unicode):
-            full_session_key = full_session_key.encode('utf-8')
+            full_session_key = full_session_key.encode("utf-8")
         if not session:
             if session.modified:
                 self.client.delete(full_session_key)
-                response.delete_cookie(app.session_cookie_name,
-                                       domain=domain, path=path)
+                response.delete_cookie(
+                    app.session_cookie_name, domain=domain, path=path
+                )
             return
 
         conditional_cookie_kwargs = {}
@@ -284,19 +295,28 @@ class MemcachedSessionInterface(SessionInterface):
             conditional_cookie_kwargs["samesite"] = self.get_cookie_samesite(app)
         expires = self.get_expiration_time(app, session)
         if not PY2:
-            val = self.serializer.dumps(dict(session), 0)
+            value = self.serializer.dumps(dict(session), 0)
         else:
-            val = self.serializer.dumps(dict(session))
-        self.client.set(full_session_key, val, self._get_memcache_timeout(
-                        total_seconds(app.permanent_session_lifetime)))
+            value = self.serializer.dumps(dict(session))
+        self.client.set(
+            full_session_key,
+            value,
+            self._get_memcache_timeout(total_seconds(app.permanent_session_lifetime)),
+        )
         if self.use_signer:
             session_id = self._get_signer(app).sign(want_bytes(session.sid))
         else:
             session_id = session.sid
-        response.set_cookie(app.session_cookie_name, session_id,
-                            expires=expires, httponly=httponly,
-                            domain=domain, path=path, secure=secure,
-                            **conditional_cookie_kwargs)
+        response.set_cookie(
+            app.session_cookie_name,
+            session_id,
+            expires=expires,
+            httponly=httponly,
+            domain=domain,
+            path=path,
+            secure=secure,
+            **conditional_cookie_kwargs,
+        )
 
 
 class FileSystemSessionInterface(SessionInterface):
@@ -316,9 +336,11 @@ class FileSystemSessionInterface(SessionInterface):
 
     session_class = FileSystemSession
 
-    def __init__(self, cache_dir, threshold, mode, key_prefix,
-                 use_signer=False, permanent=True):
+    def __init__(
+        self, cache_dir, threshold, mode, key_prefix, use_signer=False, permanent=True
+    ):
         from cachelib.file import FileSystemCache
+
         self.cache = FileSystemCache(cache_dir, threshold=threshold, mode=mode)
         self.key_prefix = key_prefix
         self.use_signer = use_signer
@@ -352,8 +374,9 @@ class FileSystemSessionInterface(SessionInterface):
         if not session:
             if session.modified:
                 self.cache.delete(self.key_prefix + session.sid)
-                response.delete_cookie(app.session_cookie_name,
-                                       domain=domain, path=path)
+                response.delete_cookie(
+                    app.session_cookie_name, domain=domain, path=path
+                )
             return
 
         conditional_cookie_kwargs = {}
@@ -363,16 +386,25 @@ class FileSystemSessionInterface(SessionInterface):
             conditional_cookie_kwargs["samesite"] = self.get_cookie_samesite(app)
         expires = self.get_expiration_time(app, session)
         data = dict(session)
-        self.cache.set(self.key_prefix + session.sid, data,
-                       total_seconds(app.permanent_session_lifetime))
+        self.cache.set(
+            self.key_prefix + session.sid,
+            data,
+            total_seconds(app.permanent_session_lifetime),
+        )
         if self.use_signer:
             session_id = self._get_signer(app).sign(want_bytes(session.sid))
         else:
             session_id = session.sid
-        response.set_cookie(app.session_cookie_name, session_id,
-                            expires=expires, httponly=httponly,
-                            domain=domain, path=path, secure=secure,
-                            **conditional_cookie_kwargs)
+        response.set_cookie(
+            app.session_cookie_name,
+            session_id,
+            expires=expires,
+            httponly=httponly,
+            domain=domain,
+            path=path,
+            secure=secure,
+            **conditional_cookie_kwargs,
+        )
 
 
 class MongoDBSessionInterface(SessionInterface):
@@ -392,10 +424,12 @@ class MongoDBSessionInterface(SessionInterface):
     serializer = pickle
     session_class = MongoDBSession
 
-    def __init__(self, client, db, collection, key_prefix, use_signer=False,
-                 permanent=True):
+    def __init__(
+        self, client, db, collection, key_prefix, use_signer=False, permanent=True
+    ):
         if client is None:
             from pymongo import MongoClient
+
             client = MongoClient()
         self.client = client
         self.store = client[db][collection]
@@ -421,15 +455,15 @@ class MongoDBSessionInterface(SessionInterface):
                 return self.session_class(sid=sid, permanent=self.permanent)
 
         store_id = self.key_prefix + sid
-        document = self.store.find_one({'id': store_id})
-        if document and document.get('expiration') <= datetime.utcnow():
+        document = self.store.find_one({"id": store_id})
+        if document and document.get("expiration") <= datetime.utcnow():
             # Delete expired session
-            self.store.remove({'id': store_id})
+            self.store.remove({"id": store_id})
             document = None
         if document is not None:
             try:
-                val = document['val']
-                data = self.serializer.loads(want_bytes(val))
+                value = document["val"]
+                data = self.serializer.loads(want_bytes(value))
                 return self.session_class(data, sid=sid)
             except:
                 return self.session_class(sid=sid, permanent=self.permanent)
@@ -441,9 +475,10 @@ class MongoDBSessionInterface(SessionInterface):
         store_id = self.key_prefix + session.sid
         if not session:
             if session.modified:
-                self.store.remove({'id': store_id})
-                response.delete_cookie(app.session_cookie_name,
-                                       domain=domain, path=path)
+                self.store.remove({"id": store_id})
+                response.delete_cookie(
+                    app.session_cookie_name, domain=domain, path=path
+                )
             return
 
         conditional_cookie_kwargs = {}
@@ -452,19 +487,26 @@ class MongoDBSessionInterface(SessionInterface):
         if self.has_same_site_capability:
             conditional_cookie_kwargs["samesite"] = self.get_cookie_samesite(app)
         expires = self.get_expiration_time(app, session)
-        val = self.serializer.dumps(dict(session))
-        self.store.update({'id': store_id},
-                          {'id': store_id,
-                           'val': val,
-                           'expiration': expires}, True)
+        value = self.serializer.dumps(dict(session))
+        self.store.update(
+            {"id": store_id},
+            {"id": store_id, "val": value, "expiration": expires},
+            True,
+        )
         if self.use_signer:
             session_id = self._get_signer(app).sign(want_bytes(session.sid))
         else:
             session_id = session.sid
-        response.set_cookie(app.session_cookie_name, session_id,
-                            expires=expires, httponly=httponly,
-                            domain=domain, path=path, secure=secure,
-                            **conditional_cookie_kwargs)
+        response.set_cookie(
+            app.session_cookie_name,
+            session_id,
+            expires=expires,
+            httponly=httponly,
+            domain=domain,
+            path=path,
+            secure=secure,
+            **conditional_cookie_kwargs,
+        )
 
 
 class SqlAlchemySessionInterface(SessionInterface):
@@ -483,10 +525,10 @@ class SqlAlchemySessionInterface(SessionInterface):
     serializer = pickle
     session_class = SqlAlchemySession
 
-    def __init__(self, app, db, table, key_prefix, use_signer=False,
-                 permanent=True):
+    def __init__(self, app, db, table, key_prefix, use_signer=False, permanent=True):
         if db is None:
             from flask_sqlalchemy import SQLAlchemy
+
             db = SQLAlchemy(app)
         self.db = db
         self.key_prefix = key_prefix
@@ -497,7 +539,7 @@ class SqlAlchemySessionInterface(SessionInterface):
         class Session(self.db.Model):
             __tablename__ = table
 
-            id = self.db.Column(self.db.Integer, primary_key=True)
+            id = self.db.Column(self.db.Integer, primary_key=True)  # noqa: A003, VNE003
             session_id = self.db.Column(self.db.String(255), unique=True)
             data = self.db.Column(self.db.LargeBinary)
             expiry = self.db.Column(self.db.DateTime)
@@ -508,7 +550,7 @@ class SqlAlchemySessionInterface(SessionInterface):
                 self.expiry = expiry
 
             def __repr__(self):
-                return '<Session data %s>' % self.data
+                return f"<Session data {self.data}>"
 
         # self.db.create_all()
         self.sql_session_model = Session
@@ -531,7 +573,8 @@ class SqlAlchemySessionInterface(SessionInterface):
 
         store_id = self.key_prefix + sid
         saved_session = self.sql_session_model.query.filter_by(
-            session_id=store_id).first()
+            session_id=store_id
+        ).first()
         if saved_session and saved_session.expiry <= datetime.utcnow():
             # Delete expired session
             self.db.session.delete(saved_session)
@@ -539,8 +582,8 @@ class SqlAlchemySessionInterface(SessionInterface):
             saved_session = None
         if saved_session:
             try:
-                val = saved_session.data
-                data = self.serializer.loads(want_bytes(val))
+                value = saved_session.data
+                data = self.serializer.loads(want_bytes(value))
                 return self.session_class(data, sid=sid)
             except:
                 return self.session_class(sid=sid, permanent=self.permanent)
@@ -551,14 +594,16 @@ class SqlAlchemySessionInterface(SessionInterface):
         path = self.get_cookie_path(app)
         store_id = self.key_prefix + session.sid
         saved_session = self.sql_session_model.query.filter_by(
-            session_id=store_id).first()
+            session_id=store_id
+        ).first()
         if not session:
             if session.modified:
                 if saved_session:
                     self.db.session.delete(saved_session)
                     self.db.session.commit()
-                response.delete_cookie(app.session_cookie_name,
-                                       domain=domain, path=path)
+                response.delete_cookie(
+                    app.session_cookie_name, domain=domain, path=path
+                )
             return
 
         conditional_cookie_kwargs = {}
@@ -567,20 +612,26 @@ class SqlAlchemySessionInterface(SessionInterface):
         if self.has_same_site_capability:
             conditional_cookie_kwargs["samesite"] = self.get_cookie_samesite(app)
         expires = self.get_expiration_time(app, session)
-        val = self.serializer.dumps(dict(session))
+        value = self.serializer.dumps(dict(session))
         if saved_session:
-            saved_session.data = val
+            saved_session.data = value
             saved_session.expiry = expires
             self.db.session.commit()
         else:
-            new_session = self.sql_session_model(store_id, val, expires)
+            new_session = self.sql_session_model(store_id, value, expires)
             self.db.session.add(new_session)
             self.db.session.commit()
         if self.use_signer:
             session_id = self._get_signer(app).sign(want_bytes(session.sid))
         else:
             session_id = session.sid
-        response.set_cookie(app.session_cookie_name, session_id,
-                            expires=expires, httponly=httponly,
-                            domain=domain, path=path, secure=secure,
-                            **conditional_cookie_kwargs)
+        response.set_cookie(
+            app.session_cookie_name,
+            session_id,
+            expires=expires,
+            httponly=httponly,
+            domain=domain,
+            path=path,
+            secure=secure,
+            **conditional_cookie_kwargs,
+        )
